@@ -30,6 +30,9 @@ import textwrap
 import warnings
 import requests
 
+from six.moves import urllib
+from distutils.version import LooseVersion
+
 from fedora.client import OpenIdBaseClient, FedoraClientError, BaseClient
 import fedora.client.openidproxyclient
 
@@ -53,9 +56,23 @@ def BodhiClient(base_url=BASE_URL, staging=False, **kwargs):
 
     log.debug('Querying bodhi API version')
     api_url = base_url + 'api_version'
-    response = requests.head(api_url)
-    if response.status_code == 200:
+    response = requests.get(api_url)
+
+    try:
+        data = response.json
+        if callable(data):
+            data = data()
+        server_version = LooseVersion(data['version'])
+    except Exception as e:
+        if 'json' in str(type(e)).lower():
+            # Claim that bodhi1 is on the server
+            server_version = LooseVersion('0.9')
+        else:
+            raise
+
+    if server_version >= LooseVersion('2.0'):
         log.debug('Bodhi2 detected')
+        base_url = 'https://{}/'.format(urllib.parse.urlparse(response.url).netloc)
         return Bodhi2Client(base_url=base_url, staging=staging, **kwargs)
     else:
         log.debug('Bodhi1 detected')
@@ -67,7 +84,7 @@ class Bodhi2Client(OpenIdBaseClient):
     def __init__(self, base_url=BASE_URL, username=None, password=None,
                  staging=False, **kwargs):
         super(Bodhi2Client, self).__init__(base_url, login_url=base_url +
-                                          'login', **kwargs)
+                'login', username=username, **kwargs)
 
         if username and password:
             self.login(username, password)
@@ -177,6 +194,8 @@ class Bodhi2Client(OpenIdBaseClient):
         if 'limit' in kwargs:  # bodhi1 compat
             kwargs['rows_per_page'] = kwargs['limit']
             del(kwargs['limit'])
+        if 'mine' in kwargs:
+            kwargs['user'] = self.username
         return self.send_request('updates', verb='GET', params=kwargs)
 
     def comment(self, update, comment, karma=0, email=None):
@@ -671,9 +690,9 @@ class Bodhi1Client(BaseClient):
             for build in update['builds'][1:]:
                 val += '\n %s' % build['nvr']
             return val
-        val = "%s\n%s\n%s\n" % ('=' * 80, '\n'.join(
-            wrap(update['title'].replace(',', ', '), width=80,
-                 initial_indent=' '*5, subsequent_indent=' '*5)), '=' * 80)
+        val = "%s\n%s\n%s\n" % ('=' * 80, '\n'.join(textwrap.wrap(
+                update['title'].replace(',', ', '), width=80,
+                initial_indent=' '*5, subsequent_indent=' '*5)), '=' * 80)
         if update['updateid']:
             val += "  Update ID: %s\n" % update['updateid']
         val += """    Release: %s
@@ -689,14 +708,14 @@ class Bodhi1Client(BaseClient):
             for bug in update['bugs']:
                 bugstr = '%s%s - %s\n' % (i and ' ' * 11 + ': ' or '',
                                           bug['bz_id'], bug['title'])
-                bugs += '\n'.join(wrap(bugstr, width=67,
-                                       subsequent_indent=' '*11+': ')) + '\n'
+                bugs += '\n'.join(textwrap.wrap(
+                    bugstr, width=67, subsequent_indent=' '*11+': ')) + '\n'
                 i += 1
             bugs = bugs[:-1]
             val += "\n       Bugs: %s" % bugs
         if update['notes']:
-            notes = wrap(update['notes'], width=67,
-                         subsequent_indent=' ' * 11 + ': ')
+            notes = textwrap.wrap(
+                update['notes'], width=67, subsequent_indent=' ' * 11 + ': ')
             val += "\n      Notes: %s" % '\n'.join(notes)
         val += """
   Submitter: %s
@@ -713,8 +732,9 @@ class Bodhi1Client(BaseClient):
                                 comment['author'], anonymous,
                                 comment['timestamp'], comment['karma']))
                 if comment['text']:
-                    text = wrap(comment['text'], initial_indent=' ' * 13,
-                                subsequent_indent=' ' * 13, width=67)
+                    text = textwrap.wrap(
+                        comment['text'], initial_indent=' ' * 13,
+                        subsequent_indent=' ' * 13, width=67)
                     comments.append('\n'.join(text))
             val += '\n'.join(comments).lstrip() + '\n'
         if update['updateid']:
